@@ -391,7 +391,16 @@ pub mod smart_wallet {
 
     #[access_control(ctx.accounts.validate())]
     pub fn init_ix_buffer(ctx: Context<InitBuffer>, eta: i64) -> Result<()> {
-        instructions::buffer_init::handler(ctx, eta)
+        instructions::buffer_init::handle_init(ctx, eta)
+    }
+
+    #[access_control(ctx.accounts.validate())]
+    pub fn init_ix_buffer_with_bundles(
+        ctx: Context<InitBuffer>,
+        eta: i64,
+        num_bundles: u8,
+    ) -> Result<()> {
+        instructions::buffer_init::handle_init_with_bundles(ctx, eta, num_bundles)
     }
 
     #[access_control(ctx.accounts.validate())]
@@ -532,7 +541,8 @@ pub struct CreateSubaccountInfo<'info> {
             &subaccount.to_bytes()
         ],
         bump,
-        payer = payer
+        payer = payer,
+        space = 8 + SubaccountInfo::LEN
     )]
     pub subaccount_info: Account<'info, SubaccountInfo>,
     /// Payer to create the [SubaccountInfo].
@@ -588,6 +598,8 @@ pub enum ErrorCode {
     BufferFinalized,
     #[msg("Buffer bundle not found.")]
     BufferBundleNotFound,
+    #[msg("Buffer index specified is out of range.")]
+    BufferBundleOutOfRange,
     #[msg("Buffer has not been finalized.")]
     BufferBundleNotFinalized,
     #[msg("Buffer bundle has already been executed.")]
